package com.ynet.life.sujrb.base;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.log.GENELog;
import com.ynet.gene.session.Session;
import com.ynet.gene.web.servlet.ModelAndView;
import com.ynet.gene.web.servlet.mvc.GENERequestController;
import com.ynet.gene.web.taskInfo.AdvertInfo;
import com.ynet.gene.web.taskInfo.HelpItem;
import com.ynet.gene.web.taskInfo.RelativeTask;
import com.ynet.gene.web.taskInfo.TaskGroup;
import com.ynet.gene.web.taskInfo.TaskInfo;
import com.ynet.gene.web.taskInfo.TaskInfoProvider;
import java.util.List;
import java.util.StringTokenizer;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/* loaded from: com_ynet_life_sujrb_base.jar:com/ynet/life/sujrb/base/PBTaskInfoXMLController.class */
public class PBTaskInfoXMLController extends GENERequestController {
    protected boolean isInit = false;
    private String helpWebContext = null;
    private String advertWebContext = null;
    protected TaskInfoProvider taskInfoProvider = null;
    private String name;
    private String userIdField;

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v18 */
    /* JADX WARN: Type inference failed for: r0v19, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v21, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v31, types: [com.ynet.life.sujrb.base.PBTaskInfoXMLController] */
    public ModelAndView doRequest(HttpServletRequest request, HttpServletResponse response) {
        if (this.openMonitor) {
            this.accessInfo.newAccess();
        }
        if (!this.isInit) {
            ?? r0 = this;
            synchronized (r0) {
                r0 = this.isInit;
                if (r0 == 0) {
                    try {
                        String rootPath = (String) request.getAttribute(GENEConstance.ATTR_ROOTPATH);
                        this.taskInfoProvider.initializeFrom(rootPath);
                        r0 = this;
                        r0.isInit = true;
                    } catch (Exception e) {
                        GENELog.log(GENEConstance.GENE_MVC, GENELog.ERROR, 0, "Failed to initialize taskinfo!", e);
                        outputContent(response, "Internal error!");
                        return null;
                    }
                }
            }
        }
        response.setContentType("text/xml; charset=UTF-8");
        response.addHeader("Cache-Control", "no-cache");
        request.getParameter("cmd");
        try {
            getSessionManager().getSession(request, response, false);
        } catch (Exception unused) {
        }
        if (this.taskInfoProvider == null) {
            outputContent(response, "Internal error!");
            GENELog.log(GENEConstance.GENE_MVC, GENELog.ERROR, 0, "TaskInfoProvider not initialize for TaskInfoController!");
            return null;
        }
        doGetTaskTree(request, response);
        return null;
    }

    private void doGetTaskTree(HttpServletRequest request, HttpServletResponse response) {
        List childs = this.taskInfoProvider.getTaskInfos((Context) null, (String) null, (String) null);
        if (childs == null) {
            outputContent(response, "Internal error!");
            GENELog.log(GENEConstance.GENE_MVC, GENELog.ERROR, 0, "TaskInfoProvider return null for ");
        } else {
            StringBuffer buf = new StringBuffer("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n<TaskModel>\n");
            buildTaskTree(childs, buf, request, response);
            buf.append("</TaskModel>");
            outputContent(response, buf.toString());
        }
    }

    private String encodeURL(HttpServletRequest request, HttpServletResponse response, String url) {
        if (this.sessionManager != null) {
            return this.sessionManager.encodeURL(request, response, url, "GET");
        }
        return response.encodeURL(url);
    }

    private void buildTaskTree(List childs, StringBuffer buf, HttpServletRequest request, HttpServletResponse response) {
        Session session = this.sessionManager.getSession(request, response, false);
        Context sessionContext = null;
        if (session != null) {
            sessionContext = (Context) session.getAttribute(GENEConstance.ATTR_CONTEXT);
        }
        for (int i = 0; i < childs.size(); i++) {
            Object obj = childs.get(i);
            if (obj instanceof TaskGroup) {
                TaskGroup group = (TaskGroup) obj;
                buf.append("\n<TaskGroup id=\"");
                buf.append(group.getId());
                buf.append("\" ");
                if (group.getDftTaskId() != null) {
                    buf.append(" dftTaskId=\"");
                    buf.append(group.getDftTaskId());
                    buf.append("\" ");
                }
                String label = group.getName();
                String label2 = getResourceValue(request, label);
                buf.append(" name=\"");
                buf.append(label2);
                buf.append("\" ");
                String url = group.getAction();
                if (url != null) {
                    buf.append(" action=\"");
                    buf.append(normalizeTextValue(url));
                    buf.append("\" ");
                }
                String target = group.getTarget();
                if (target != null) {
                    buf.append(" target=\"");
                    buf.append(target);
                    buf.append("\" ");
                }
                if (group.getChilds() != null && group.getChilds().size() > 0) {
                    buf.append(">");
                    buildTaskTree(group.getChilds(), buf, request, response);
                    buf.append("\n</TaskGroup>");
                } else {
                    buf.append("/>");
                }
            } else if (obj instanceof TaskInfo) {
                TaskInfo task = (TaskInfo) obj;
                buf.append("\n<TaskInfo id=\"");
                buf.append(task.getId());
                buf.append("\" ");
                buf.append(" action=\"");
                buf.append(normalizeTextValue(task.getAction()));
                buf.append("\" ");
                String label3 = task.getName();
                String label4 = getResourceValue(request, label3);
                buf.append(" name=\"");
                buf.append(label4);
                buf.append("\" ");
                String target2 = task.getTarget();
                if (target2 != null) {
                    buf.append(" target=\"");
                    buf.append(target2);
                    buf.append("\" ");
                }
                boolean hasChild = false;
                if (task.getRelativeTasks() != null) {
                    buf.append(">");
                    List list = task.getRelativeTasks();
                    for (int k = 0; k < list.size(); k++) {
                        RelativeTask rt = (RelativeTask) list.get(k);
                        buf.append("\n<relatedTask taskId=\"");
                        buf.append(rt.getTaskId());
                        buf.append("\"/>");
                    }
                    hasChild = true;
                }
                if (task.getHelpItems() != null) {
                    if (!hasChild) {
                        buf.append(">");
                    }
                    hasChild = true;
                    List list2 = task.getHelpItems();
                    for (int k2 = 0; k2 < list2.size(); k2++) {
                        HelpItem ht = (HelpItem) list2.get(k2);
                        buf.append("\n<helpItem label=\"");
                        buf.append(getResourceValue(request, ht.getLabel()));
                        buf.append("\" href=\"");
                        String value = ht.getHref();
                        if (ht.getWebContext() != null) {
                            value = "/" + ht.getWebContext() + "/" + ht.getHref();
                        } else if (this.helpWebContext != null) {
                            value = "/" + this.helpWebContext + "/" + ht.getHref();
                        }
                        buf.append(normalizeTextValue(value));
                        buf.append("\"/>");
                    }
                }
                if (task.getAdvertInfo() != null) {
                    if (!hasChild) {
                        buf.append(">");
                    }
                    hasChild = true;
                    AdvertInfo advertInfo = task.getAdvertInfo();
                    buf.append("\n<advertItem href=\"");
                    StringBuffer hrefBuf = new StringBuffer();
                    if (advertInfo.getWebContext() != null) {
                        hrefBuf.append("/" + advertInfo.getWebContext() + "/" + advertInfo.getHref());
                    } else if (this.advertWebContext != null) {
                        hrefBuf.append("/" + this.advertWebContext + "/" + advertInfo.getHref());
                    } else {
                        hrefBuf.append(advertInfo.getHref());
                    }
                    if (advertInfo.getAppendParam() != null) {
                        StringTokenizer tk = new StringTokenizer(advertInfo.getAppendParam(), ";");
                        boolean isFirst = true;
                        while (tk.hasMoreTokens()) {
                            String paramName = tk.nextToken();
                            if (paramName.equals("taskId")) {
                                if (isFirst) {
                                    hrefBuf.append("?");
                                    isFirst = false;
                                } else {
                                    hrefBuf.append("&");
                                }
                                hrefBuf.append(paramName);
                                hrefBuf.append("=");
                                hrefBuf.append(task.getId());
                            } else if (sessionContext != null) {
                                try {
                                    String value2 = (String) sessionContext.getDataValue(paramName);
                                    if (isFirst) {
                                        hrefBuf.append("?");
                                        isFirst = false;
                                    } else {
                                        hrefBuf.append("&");
                                    }
                                    hrefBuf.append(paramName);
                                    hrefBuf.append("=");
                                    hrefBuf.append(value2);
                                } catch (Exception unused) {
                                }
                            }
                        }
                    }
                    buf.append(normalizeTextValue(hrefBuf.toString()));
                    buf.append("\"/>");
                }
                if (hasChild) {
                    buf.append("\n</TaskInfo>");
                } else {
                    buf.append("/>");
                }
            }
        }
    }

    private void outputContent(HttpServletResponse response, String content) {
        try {
            response.getOutputStream().write(content.getBytes("UTF-8"));
        } catch (Exception e) {
            GENELog.log(GENEConstance.GENE_MVC, GENELog.ERROR, 0, "Failed to output taskInfo content.", e);
        }
    }

    public String getName() {
        return this.name;
    }

    public void setName(String value) {
        this.name = value;
    }

    public void setId(String value) {
        this.name = value;
    }

    public long getLastModified(HttpServletRequest request) {
        return -1L;
    }

    public void initialize() {
    }

    public TaskInfoProvider getTaskInfoProvider() {
        return this.taskInfoProvider;
    }

    public void setTaskInfoProvider(TaskInfoProvider taskInfoProvider) {
        this.taskInfoProvider = taskInfoProvider;
    }

    public String getUserIdField() {
        return this.userIdField;
    }

    public void setUserIdField(String userIdField) {
        this.userIdField = userIdField;
    }

    public String getAdvertWebContext() {
        return this.advertWebContext;
    }

    public void setAdvertWebContext(String advertWebContext) {
        this.advertWebContext = advertWebContext;
    }

    public String getHelpWebContext() {
        return this.helpWebContext;
    }

    public void setHelpWebContext(String helpWebContext) {
        this.helpWebContext = helpWebContext;
    }

    protected String normalizeTextValue(String s) {
        StringBuffer str = new StringBuffer();
        int len = s != null ? s.length() : 0;
        for (int i = 0; i < len; i++) {
            char ch = s.charAt(i);
            switch (ch) {
                case '\"':
                    str.append("&quot;");
                    break;
                case '&':
                    str.append("&amp;");
                    break;
                case '<':
                    str.append("&lt;");
                    break;
                case '>':
                    str.append("&gt;");
                    break;
                default:
                    str.append(ch);
                    break;
            }
        }
        return str.toString();
    }
}
